@@ -9,12 +9,12 @@ class Code(IntEnum):
     FAILED = 2
 
 
-def error_dict(msg: str) -> dict:
-    return {"code": Code.FAILED, "msg": msg, "data": {}}
+def error_dict(msg: str, data: dict) -> dict:
+    return {"code": Code.FAILED, "msg": msg, "data": data}
 
 
-def error_response(msg: str) -> JsonResponse:
-    return JsonResponse(data=error_dict(msg))
+def error_response(msg: str, data: dict) -> JsonResponse:
+    return JsonResponse(data=error_dict(msg, data))
 
 
 def success_dict(msg: str, data: dict) -> dict:
